Scope

Trait Scope 

pub trait Scope<Q, S>
where Q: RawState,
{ // Required methods fn current_state(&self) -> &State<Q>; fn current_symbol(&self) -> &S; }
The Scope trait is used to describe objects containing information or references to the current state and symbol of a Turing machine.

Required Methods

fn current_state(&self) -> &State<Q>

fn current_symbol(&self) -> &S

Implementations on Foreign Types

Source

impl<Q, S> Scope<Q, S> for (State<Q>, S)
where Q: RawState,

Source

impl<Q, S> Scope<Q, S> for Head<Q, S>
where Q: RawState,

Implementors

Source

impl<Q, S> Scope<Q, S> for Rule<Q, S>
where Q: RawState,